@@ -17,7 +17,7 @@ __PACKAGE__->add_property($_) for qw(etcdir installed_etcdir);
 __PACKAGE__->add_property(with => []);
 
 # Set dual_life to true to force dual-life modules such as Pod::Simple to be
-# incliuded in the bundle directory.
+# included in the bundle directory.
 # --dual_life 1
 __PACKAGE__->add_property(dual_life => 0);
 
@@ -318,7 +318,7 @@ sub _set_findbin {
     local $^I = '';
     local @ARGV = ($file);
     while (<>) {
-        s{^BEGIN}{use FindBin;\nuse lib "\$FindBin::RealBin/../lib/perl5";\nBEGIN};
+        s{^use App::Sqitch}{use FindBin;\nuse lib "\$FindBin::RealBin/../lib/perl5";\nuse App::Sqitch};
         print;
     }
 }
