@@ -155,6 +155,7 @@ CREATE TABLE events (
 
 DELIMITER |
 
+-- ## BEGIN checkit
 CREATE FUNCTION checkit(doit INTEGER, message VARCHAR(256)) RETURNS INTEGER DETERMINISTIC
 BEGIN
     IF doit IS NULL OR doit = 0 THEN
@@ -163,26 +164,25 @@ BEGIN
     RETURN doit;
 END;
 |
+-- ## END checkit
 
 CREATE TRIGGER ck_insert_dependency BEFORE INSERT ON dependencies
 FOR EACH ROW BEGIN
-    -- DO does not work. https://bugs.mysql.com/bug.php?id=69647
-    SET @dummy := checkit(
-            (NEW.type = 'require'  AND NEW.dependency_id IS NOT NULL)
-         OR (NEW.type = 'conflict' AND NEW.dependency_id IS NULL),
-        'Type must be "require" with dependency_id set or "conflict" with dependency_id not set'
-    );
+    IF (NEW.type = 'require' AND NEW.dependency_id IS NULL)
+    OR (NEW.type = 'conflict' AND NEW.dependency_id IS NOT NULL)
+    THEN
+        SIGNAL SQLSTATE 'ERR0R' SET MESSAGE_TEXT = 'Type must be "require" with dependency_id set or "conflict" with dependency_id not set';
+    END IF;
 END;
 |
 
 CREATE TRIGGER ck_update_dependency BEFORE UPDATE ON dependencies
 FOR EACH ROW BEGIN
-    -- DO does not work. https://bugs.mysql.com/bug.php?id=69647
-    SET @dummy := checkit(
-            (NEW.type = 'require'  AND NEW.dependency_id IS NOT NULL)
-         OR (NEW.type = 'conflict' AND NEW.dependency_id IS NULL),
-        'Type must be "require" with dependency_id set or "conflict" with dependency_id not set'
-    );
+    IF (NEW.type = 'require'  AND NEW.dependency_id IS NULL)
+    OR (NEW.type = 'conflict' AND NEW.dependency_id IS NOT NULL)
+    THEN
+        SIGNAL SQLSTATE 'ERR0R' SET MESSAGE_TEXT = 'Type must be "require" with dependency_id set or "conflict" with dependency_id not set';
+    END IF;
 END;
 |
 
